@@ -6,15 +6,94 @@ Twelve Plus Thirty
 
 from scipy.constants import golden
 
-from ..cage import Cage
-from ..vertices import _LinearCageVertex, _NonLinearCageVertex
 from ...topology_graph import Edge
+from ..cage import Cage
+from ..vertices import LinearVertex, NonLinearVertex
 
 
 class TwelvePlusThirty(Cage):
     """
     Represents a icosahedron cage topology graph.
 
+    Unoptimized construction
+
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock(
+            smiles='BrCCBr',
+            functional_groups=[stk.BromoFactory()],
+        )
+        bb2 = stk.BuildingBlock(
+            smiles='BrC1C(Br)C(Br)C(Br)C1Br',
+            functional_groups=[stk.BromoFactory()],
+        )
+        cage = stk.ConstructedMolecule(
+            topology_graph=stk.cage.TwelvePlusThirty((bb1, bb2)),
+        )
+
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    cage.get_atoms(),
+                    cage.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=bond.get_order(),
+                ) for bond in cage.get_bonds()
+            ),
+        )
+
+    :class:`.Collapser` optimized construction
+
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock(
+            smiles='BrCCBr',
+            functional_groups=[stk.BromoFactory()],
+        )
+        bb2 = stk.BuildingBlock(
+            smiles='BrC1C(Br)C(Br)C(Br)C1Br',
+            functional_groups=[stk.BromoFactory()],
+        )
+        cage = stk.ConstructedMolecule(
+            topology_graph=stk.cage.TwelvePlusThirty(
+                building_blocks=(bb1, bb2),
+                optimizer=stk.Collapser(),
+            ),
+        )
+
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    cage.get_atoms(),
+                    cage.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=bond.get_order(),
+                ) for bond in cage.get_bonds()
+            ),
+        )
+
     Nonlinear building blocks with five functional groups are
     required for this topology.
 
@@ -36,141 +115,141 @@ class TwelvePlusThirty(Cage):
 
     # Vertices of a regular origin-centred icosahedron
     # Source: http://eusebeia.dyndns.org/4d/icosahedron
-    _vertex_prototypes = (
-        _NonLinearCageVertex(0, [0, 1, golden]),
-        _NonLinearCageVertex(1, [0, -1, golden]),
-        _NonLinearCageVertex(2, [0, 1, -golden]),
-        _NonLinearCageVertex(3, [0, -1, -golden]),
-        _NonLinearCageVertex(4, [1, golden, 0]),
-        _NonLinearCageVertex(5, [-1, golden, 0]),
-        _NonLinearCageVertex(6, [1, -golden, 0]),
-        _NonLinearCageVertex(7, [-1, -golden, 0]),
-        _NonLinearCageVertex(8, [golden, 0, 1]),
-        _NonLinearCageVertex(9, [-golden, 0, 1]),
-        _NonLinearCageVertex(10, [golden, 0, -1]),
-        _NonLinearCageVertex(11, [-golden, 0, -1])
+    _non_linears = (
+        NonLinearVertex(0, [0, 1, golden]),
+        NonLinearVertex(1, [0, -1, golden]),
+        NonLinearVertex(2, [0, 1, -golden]),
+        NonLinearVertex(3, [0, -1, -golden]),
+        NonLinearVertex(4, [1, golden, 0]),
+        NonLinearVertex(5, [-1, golden, 0]),
+        NonLinearVertex(6, [1, -golden, 0]),
+        NonLinearVertex(7, [-1, -golden, 0]),
+        NonLinearVertex(8, [golden, 0, 1]),
+        NonLinearVertex(9, [-golden, 0, 1]),
+        NonLinearVertex(10, [golden, 0, -1]),
+        NonLinearVertex(11, [-golden, 0, -1])
     )
 
     _vertex_prototypes = (
-        *_vertex_prototypes,
-        _LinearCageVertex.init_at_center(
+        *_non_linears,
+        LinearVertex.init_at_center(
             id=12,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[1]),
+            vertices=(_non_linears[0], _non_linears[1]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=13,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[9]),
+            vertices=(_non_linears[0], _non_linears[9]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=14,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[5]),
+            vertices=(_non_linears[0], _non_linears[5]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=15,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[4]),
+            vertices=(_non_linears[0], _non_linears[4]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=16,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[8]),
+            vertices=(_non_linears[0], _non_linears[8]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=17,
-            vertices=(_vertex_prototypes[8], _vertex_prototypes[1]),),
-        _LinearCageVertex.init_at_center(
+            vertices=(_non_linears[8], _non_linears[1]),),
+        LinearVertex.init_at_center(
             id=18,
-            vertices=(_vertex_prototypes[1], _vertex_prototypes[9]),
+            vertices=(_non_linears[1], _non_linears[9]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=19,
-            vertices=(_vertex_prototypes[9], _vertex_prototypes[5]),
+            vertices=(_non_linears[9], _non_linears[5]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=20,
-            vertices=(_vertex_prototypes[5], _vertex_prototypes[4]),
+            vertices=(_non_linears[5], _non_linears[4]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=21,
-            vertices=(_vertex_prototypes[4], _vertex_prototypes[8]),
+            vertices=(_non_linears[4], _non_linears[8]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=22,
-            vertices=(_vertex_prototypes[5], _vertex_prototypes[2]),
+            vertices=(_non_linears[5], _non_linears[2]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=23,
-            vertices=(_vertex_prototypes[5], _vertex_prototypes[11]),
+            vertices=(_non_linears[5], _non_linears[11]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=24,
-            vertices=(_vertex_prototypes[9], _vertex_prototypes[11]),
+            vertices=(_non_linears[9], _non_linears[11]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=25,
-            vertices=(_vertex_prototypes[9], _vertex_prototypes[7]),
+            vertices=(_non_linears[9], _non_linears[7]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=26,
-            vertices=(_vertex_prototypes[1], _vertex_prototypes[7]),
+            vertices=(_non_linears[1], _non_linears[7]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=27,
-            vertices=(_vertex_prototypes[1], _vertex_prototypes[6]),
+            vertices=(_non_linears[1], _non_linears[6]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=28,
-            vertices=(_vertex_prototypes[8], _vertex_prototypes[6]),
+            vertices=(_non_linears[8], _non_linears[6]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=29,
-            vertices=(_vertex_prototypes[8], _vertex_prototypes[10]),
+            vertices=(_non_linears[8], _non_linears[10]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=30,
-            vertices=(_vertex_prototypes[4], _vertex_prototypes[10]),
+            vertices=(_non_linears[4], _non_linears[10]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=31,
-            vertices=(_vertex_prototypes[4], _vertex_prototypes[2]),
+            vertices=(_non_linears[4], _non_linears[2]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=32,
-            vertices=(_vertex_prototypes[2], _vertex_prototypes[11]),
+            vertices=(_non_linears[2], _non_linears[11]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=33,
-            vertices=(_vertex_prototypes[11], _vertex_prototypes[7]),
+            vertices=(_non_linears[11], _non_linears[7]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=34,
-            vertices=(_vertex_prototypes[7], _vertex_prototypes[6]),
+            vertices=(_non_linears[7], _non_linears[6]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=35,
-            vertices=(_vertex_prototypes[6], _vertex_prototypes[10]),
+            vertices=(_non_linears[6], _non_linears[10]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=36,
-            vertices=(_vertex_prototypes[10], _vertex_prototypes[2]),
+            vertices=(_non_linears[10], _non_linears[2]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=37,
-            vertices=(_vertex_prototypes[2], _vertex_prototypes[3]),
+            vertices=(_non_linears[2], _non_linears[3]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=38,
-            vertices=(_vertex_prototypes[11], _vertex_prototypes[3]),
+            vertices=(_non_linears[11], _non_linears[3]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=39,
-            vertices=(_vertex_prototypes[7], _vertex_prototypes[3]),
+            vertices=(_non_linears[7], _non_linears[3]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=40,
-            vertices=(_vertex_prototypes[6], _vertex_prototypes[3]),
+            vertices=(_non_linears[6], _non_linears[3]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=41,
-            vertices=(_vertex_prototypes[10], _vertex_prototypes[3]),
+            vertices=(_non_linears[10], _non_linears[3]),
         )
     )
 
